==> prestashop_1.0.zip: prestashop_1.0/translations/fr/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Retour n&deg;';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Avoir n&deg;';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Facture n&deg;';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Une version &eacute;lectronique est conserv&eacute;e sur votre compte. Pour y acc&eacute;der, identifiez-vous sur le site';
$_LANGPDF['PDF_invoicef14e57cfbfd08615bbb665cb803f46b1'] = 'avec vos identifiants (cr&eacute;&eacute;s lors de votre premi&egrave;re commande).';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Si&egrave;ge social';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Details :';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'T&eacute;l&eacute;phone :';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'du';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Nous avons bien enregistr&eacute; votre demande de retour.';
$_LANGPDF['PDF_invoice661532e32cb608c8ae07d8a20215a958'] = 'Nous vous rappelons que votre colis doit nous &ecirc;tre retourn&eacute; dans les 7 jours apr&egrave;s r&eacute;ception de votre commande.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste des produits faisant l\'objet d\'un retour :';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Votre n&deg; de retour :';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoice80fb5b9230a258ff2e249f1148e726fc'] = 'Merci de faire figurer ce num&eacute;ro sur votre colis de retour.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RAPPEL :';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Tous les produits doivent &ecirc;tre retourn&eacute;s dans leur emballage et leur &eacute;tat d\'origine.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Veuillez imprimer ce document et le glisser dans votre colis.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Le paquet devra &ecirc;tre envoy&eacute; &agrave; l\'adresse suivante :';
$_LANGPDF['PDF_invoice8a060230ab24c7f6a92f3e2b06ed171a'] = 'D&egrave;s r&eacute;ception de votre colis nous proc&eacute;derons alors au remboursement du montant de votre commande et vous en informerons par mail.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Merci de nous contacter pour toutes questions.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si les conditions de retour list&eacute;es ci-dessus n\'&eacute;taient pas respect&eacute;es,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nous nous r&eacute;servons le droit de refuser votre colis ou votre remboursement.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'R&eacute;f&eacute;rence';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Qt&eacute;';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturation';
$_LANGPDF['PDF_invoicef4d5b114119bfdbdc5f3d9472a46fc7b'] = 'Date :';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transporteur :';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'M&eacute;thode de paiement :';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Date d\'exp&eacute;dition :';
$_LANGPDF['PDF_invoicedd187730fdd36d3e727190ce86cae11b'] = 'Origine :';
$_LANGPDF['PDF_invoice1d449f39dc4e1dbfc87e588ace899356'] = 'Total produits TTC';
$_LANGPDF['PDF_invoiceb76c1a1463e45cece931ef4467c0bdf8'] = 'Total r&eacute;ductions';
$_LANGPDF['PDF_invoice7a5b34426b4672759796f035bbc2674e'] = 'Total emballage';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Total livraison';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total TTC';
$_LANGPDF['PDF_invoice7d3548c5b974fa710296c1b3f5564753'] = 'Eco-participation';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Prix unitaire';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total HT';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'R&eacute;duction :';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'D&eacute;tail de taxe';
$_LANGPDF['PDF_invoicea7fa76ae71664800f8994ad52581e3c2'] = '% de la taxe';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Taxe totale';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_LANGPDF['PDF_invoiceba794350deb07c0c96fe73bd12239059'] = 'Emballage';
?>

==> prestashop_1.1.0.1.zip: prestashop_1.1.0.1/translations/fr/pdf.php <==
<?php

global $_LANGPDF;
$_LANGPDF = array();
$_LANGPDF['PDF_invoicee0036b67b754e9f6442f9f9e6b200c33'] = 'Retour n&deg;';
$_LANGPDF['PDF_invoice77c3e447f60541a1c346a08134078c7f'] = 'Avoir n&deg;';
$_LANGPDF['PDF_invoicecb5efbba6a6babef9082ca6976928ca7'] = 'Bon de livraison n&deg;';
$_LANGPDF['PDF_invoicefe4da50838bb10dcbf1bf8dcd9b12ab5'] = 'Facture n&deg;';
$_LANGPDF['PDF_invoice8dae339c20973fe3fcdeb5f2e8e8f894'] = 'Une version &eacute;lectronique est conserv&eacute;e sur votre compte. Pour y acc&eacute;der, identifiez-vous sur le site';
$_LANGPDF['PDF_invoice15b57bef332e7e0327d89fe93711a954'] = 'Une version &eacute;lectronique est conserv&eacute;e sur votre compte. Pour y acc&eacute;der, identifiez-vous sur le site';
$_LANGPDF['PDF_invoicef14e57cfbfd08615bbb665cb803f46b1'] = 'avec vos identifiants (cr&eacute;&eacute;s lors de votre premi&egrave;re commande).';
$_LANGPDF['PDF_invoice808a04117534f9dfb63b9accd7efc609'] = 'Si&egrave;ge social';
$_LANGPDF['PDF_invoice2babe53026309ed1bc4d26626dbaf9b3'] = 'Details :';
$_LANGPDF['PDF_invoicea54cedc1e053a70d4a6319feccf531ca'] = 'T&eacute;l&eacute;phone :';
$_LANGPDF['PDF_invoiced98a07f84921b24ee30f86fd8cd85c3c'] = 'du';
$_LANGPDF['PDF_invoice88be9ea838e21273267409d76af3b284'] = 'Nous avons bien enregistr&eacute; votre demande de retour.';
$_LANGPDF['PDF_invoicee209d63b7260d6ce2c7873df4c2ee73c'] = 'Nous vous rappelons que votre colis doit nous &ecirc;tre retourn&eacute; dans les';
$_LANGPDF['PDF_invoice1926fda32a52ec84f205a65b98f8bbb8'] = 'jours apr&egrave;s r&eacute;ception de votre commande.';
$_LANGPDF['PDF_invoice3d2f834cf879baebfdbe52c1c14d9d53'] = 'Liste des produits faisant l\'objet d\'un retour :';
$_LANGPDF['PDF_invoice9fad4fa5f3fa5caad9b506bbdd9f35d4'] = 'Votre n&deg; de retour :';
$_LANGPDF['PDF_invoicefb902bc4807c307b9309f2b528b96f2b'] = 'RET';
$_LANGPDF['PDF_invoice80fb5b9230a258ff2e249f1148e726fc'] = 'Merci de faire figurer ce num&eacute;ro sur votre colis de retour.';
$_LANGPDF['PDF_invoicefbbd47b7e45c0ad3fe0bf70539b5a2d4'] = 'RAPPEL :';
$_LANGPDF['PDF_invoicea3852e23346f6f1e29e1683991690af3'] = '- Tous les produits doivent &ecirc;tre retourn&eacute;s dans leur emballage et leur &eacute;tat d\'origine.';
$_LANGPDF['PDF_invoice0e9a828e54995e48083a072205493fb4'] = '- Veuillez imprimer ce document et le glisser dans votre colis.';
$_LANGPDF['PDF_invoicead500469c8dc258dcebb89c9efe15de7'] = '- Le paquet devra &ecirc;tre envoy&eacute; &agrave; l\'adresse suivante :';
$_LANGPDF['PDF_invoice8a060230ab24c7f6a92f3e2b06ed171a'] = 'D&egrave;s r&eacute;ception de votre colis nous proc&eacute;derons alors au remboursement du montant de votre commande et vous en informerons par mail.';
$_LANGPDF['PDF_invoice2d0620950a4d96ae301ba7a98e528714'] = 'Merci de nous contacter pour toutes questions.';
$_LANGPDF['PDF_invoice25e12a86579549b9f88117615eb05e4b'] = 'Si les conditions de retour list&eacute;es ci-dessus n\'&eacute;taient pas respect&eacute;es,';
$_LANGPDF['PDF_invoicec896fe3f3895e8ef54194eec601b8f3c'] = 'nous nous r&eacute;servons le droit de refuser votre colis ou votre remboursement.';
$_LANGPDF['PDF_invoiceb5a7adde1af5c87d7fd797b6245c2a39'] = 'Description';
$_LANGPDF['PDF_invoice63d5049791d9d79d86e9a108b0a999ca'] = 'R&eacute;f&eacute;rence';
$_LANGPDF['PDF_invoice03ab340b3f99e03cff9e84314ead38c0'] = 'Qt&eacute;';
$_LANGPDF['PDF_invoice065ab3a28ca4f16f55f103adc7d0226f'] = 'Livraison';
$_LANGPDF['PDF_invoice6bdf2efe1a99072849d4e87baee37dbe'] = 'Facturation';
$_LANGPDF['PDF_invoiced1228f5476d15142b1358ae4b5fa2454'] = 'Commande n&deg;';
$_LANGPDF['PDF_invoicef8617a92ba0a0a4eabee724eab7c9f48'] = 'Transporteur :';
$_LANGPDF['PDF_invoicec1f6368d15f7c13c4e5e8f70c68c747f'] = 'M&eacute;thode de paiement :';
$_LANGPDF['PDF_invoicea3a79b28bc45b7fd393effd056b917e1'] = 'Date d\'exp&eacute;dition :';
$_LANGPDF['PDF_invoice1d449f39dc4e1dbfc87e588ace899356'] = 'Total produits TTC';
$_LANGPDF['PDF_invoiceb76c1a1463e45cece931ef4467c0bdf8'] = 'Total r&eacute;ductions';
$_LANGPDF['PDF_invoice7a5b34426b4672759796f035bbc2674e'] = 'Total emballage';
$_LANGPDF['PDF_invoicef4e8b53a114e5a17d051ab84d326cae5'] = 'Total livraison';
$_LANGPDF['PDF_invoiceae5c2883df7651730799e1036984a6a3'] = 'Total TTC';
$_LANGPDF['PDF_invoice7d3548c5b974fa710296c1b3f5564753'] = 'Eco-participation';
$_LANGPDF['PDF_invoiceafd42dfebce46ec93972b2e0cbb8b83f'] = 'Prix unitaire';
$_LANGPDF['PDF_invoicecd6576cc33506a6c44e2debbde5c14d9'] = 'Total HT';
$_LANGPDF['PDF_invoice96b0141273eabab320119c467cdcaf17'] = 'Total';
$_LANGPDF['PDF_invoicea1e7379abfdbc3b8e03506e5489c6110'] = 'R&eacute;duction :';
$_LANGPDF['PDF_invoice42c26bf38ece1dcd27aca8c6f8c076ed'] = 'D&eacute;tails de taxe';
$_LANGPDF['PDF_invoicea7fa76ae71664800f8994ad52581e3c2'] = '% de la taxe';
$_LANGPDF['PDF_invoiceb602e0d0c6a72053d0a5be60cb2f8126'] = 'Taxe totale';
$_LANGPDF['PDF_invoice068f80c7519d0528fb08e82137a72131'] = 'Produits';
$_LANGPDF['PDF_invoice914419aa32f04011357d3b604a86d7eb'] = 'Transporteur';
$_LANGPDF['PDF_invoiceba794350deb07c0c96fe73bd12239059'] = 'Emballage';

?>
